@@ -9,11 +9,11 @@ import gettext
 from gettext import gettext as _
 gettext.textdomain('project_name')
 
-import gtk
+from gi.repository import Gtk # pylint: disable=E0611
 
 from python_name import camel_case_nameWindow
 
-from python_name_lib import set_up_logging, preferences, get_version
+from python_name_lib import set_up_logging, get_version
 
 def parse_options():
     """Support for command line options"""
@@ -29,20 +29,7 @@ def main():
     'constructor for your class instances'
     parse_options()
 
-    # preferences
-    # set some values for our first session
-    # TODO: replace defaults with your own values
-    default_preferences = {
-    'example_entry': 'I remember stuff',
-    }
-    preferences.update(default_preferences)
-    # user's stored preferences are used for 2nd and subsequent sessions
-    preferences.db_connect()
-    preferences.load()
-
     # Run the application.    
     window = camel_case_nameWindow.camel_case_nameWindow()
     window.show()
-    gtk.main()
-    
-    preferences.save()
+    Gtk.main()
