@@ -5,9 +5,8 @@
 
 '''Enhances builder connections, provides object to access glade objects'''
 
-import gobject  # pylint: disable=E0611
+from gi.repository import GObject, Gtk # pylint: disable=E0611
 
-import gtk
 import inspect
 import functools
 import logging
@@ -23,8 +22,8 @@ from xml.etree.cElementTree import ElementTree
 
 
 # pylint: disable=R0904
-# the many public methods is a feature of gtk.Builder
-class Builder(gtk.Builder):
+# the many public methods is a feature of Gtk.Builder
+class Builder(Gtk.Builder):
     ''' extra features
     connects glade defined handler to default_handler if necessary
     auto connects widget to handler with matching name or alias
@@ -34,7 +33,7 @@ class Builder(gtk.Builder):
     '''
 
     def __init__(self):
-        gtk.Builder.__init__(self)
+        Gtk.Builder.__init__(self)
         self.widgets = {}
         self.glade_handler_dict = {}
         self.connections = []
@@ -50,7 +49,7 @@ class Builder(gtk.Builder):
     An apprentice guru might wonder which signal does what he wants,
     now he can define any likely candidates in glade and notice which
     ones get triggered when he plays with the project.
-    this method does not appear in gtk.Builder'''
+    this method does not appear in Gtk.Builder'''
         logger.debug('''tried to call non-existent function:%s()
         expected in %s
         args:%s
@@ -60,12 +59,12 @@ class Builder(gtk.Builder):
     def get_name(self, widget):
         ''' allows a handler to get the name (id) of a widget
 
-        this method does not appear in gtk.Builder'''
+        this method does not appear in Gtk.Builder'''
         return self._reverse_widget_dict.get(widget)
 
     def add_from_file(self, filename):
         '''parses xml file and stores wanted details'''
-        gtk.Builder.add_from_file(self, filename)
+        Gtk.Builder.add_from_file(self, filename)
 
         # extract data for the extra interfaces
         tree = ElementTree()
@@ -121,7 +120,7 @@ class Builder(gtk.Builder):
                  item[0], filename)
 
         # connect glade define handlers
-        gtk.Builder.connect_signals(self, connection_dict)
+        Gtk.Builder.connect_signals(self, connection_dict)
 
         # let's tell the user how we applied the glade design
         for connection in self.connections:
@@ -133,7 +132,7 @@ class Builder(gtk.Builder):
         '''Creates the ui object with widgets as attributes
 
         connects signals by 2 methods
-        this method does not appear in gtk.Builder'''
+        this method does not appear in Gtk.Builder'''
 
         result = UiFactory(self.widgets)
 
@@ -196,9 +195,25 @@ def make_pyname(name):
     return pyname
 
 
+# Until bug https://bugzilla.gnome.org/show_bug.cgi?id=652127 is fixed, we 
+# need to reimplement inspect.getmembers.  GObject introspection doesn't
+# play nice with it.
+def getmembers(obj, check):
+    members = []
+    for k in dir(obj):
+        try:
+            attr = getattr(obj, k)
+        except:
+            continue
+        if check(attr):
+            members.append((k, attr))
+    members.sort()
+    return members
+
+
 def dict_from_callback_obj(callback_obj):
     '''a dictionary interface to callback_obj'''
-    methods = inspect.getmembers(callback_obj, inspect.ismethod)
+    methods = getmembers(callback_obj, inspect.ismethod)
 
     aliased_methods = [x[1] for x in methods if hasattr(x[1], 'aliases')]
 
@@ -238,15 +253,16 @@ def auto_connect_by_name(callback_obj, builder):
         try:
             widget_type = type(widget)
             while widget_type:
-                signal_ids.extend(gobject.signal_list_ids(widget_type))
-                widget_type = gobject.type_parent(widget_type)
+                signal_ids.extend(GObject.signal_list_ids(widget_type))
+                widget_type = GObject.type_parent(widget_type)
         except RuntimeError:  # pylint wants a specific error
             pass
-        signal_names = [gobject.signal_name(sid) for sid in signal_ids]
+        signal_names = [GObject.signal_name(sid) for sid in signal_ids]
 
         # Now, automatically find any the user didn't specify in glade
         for sig in signal_names:
             # using convention suggested by glade
+            sig = sig.replace("-", "_")
             handler_names = ["on_%s_%s" % (widget_name, sig)]
 
             # Using the convention that the top level window is not
